==> openjdk-lts_11.0.23+9.orig.tar.xz: openjdk-11-11.0.23+9/test/hotspot/jtreg/gc/arguments/TestDisableDefaultGC.java <==
/*
 * Copyright (c) 2016, 2019, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

package gc.arguments;

/*
 * @test TestDisableDefaultGC
 * @summary Test that the VM complains when the default GC is disabled and no other GC is specified
 * @bug 8068579
 * @key gc
 * @library /test/lib
 * @library /
 * @requires vm.gc=="null"
 * @modules java.base/jdk.internal.misc
 *          java.management
 * @run driver gc.arguments.TestDisableDefaultGC
 */

import jdk.test.lib.process.ProcessTools;
import jdk.test.lib.process.OutputAnalyzer;

public class TestDisableDefaultGC {
    public static void main(String[] args) throws Exception {
        // Start VM, disabling all possible default GCs
        ProcessBuilder pb = GCArguments.createJavaProcessBuilder("-XX:-UseSerialGC",
                                                                 "-XX:-UseParallelGC",
                                                                 "-XX:-UseG1GC",
                                                                 "-XX:-UseConcMarkSweepGC",
                                                                 "-XX:+UnlockExperimentalVMOptions",
                                                                 "-XX:-UseZGC",
                                                                 "-version");
        OutputAnalyzer output = new OutputAnalyzer(pb.start());
        output.shouldMatch("Garbage collector not selected");
        output.shouldHaveExitValue(1);
    }
}

==> openjdk-lts_11.0.29+7.orig.tar.xz: openjdk-11-11.0.29+7/test/hotspot/jtreg/gc/arguments/TestDisableDefaultGC.java <==
/*
 * Copyright (c) 2016, 2023, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

package gc.arguments;

/*
 * @test TestDisableDefaultGC
 * @summary Test that the VM complains when the default GC is disabled and no other GC is specified
 * @bug 8068579
 * @key gc
 * @library /test/lib
 * @library /
 * @requires vm.gc=="null"
 * @modules java.base/jdk.internal.misc
 *          java.management
 * @run driver gc.arguments.TestDisableDefaultGC
 */

import jdk.test.lib.process.ProcessTools;
import jdk.test.lib.process.OutputAnalyzer;

public class TestDisableDefaultGC {
    public static void main(String[] args) throws Exception {
        // Start VM, disabling all possible default GCs
        ProcessBuilder pb = GCArguments.createTestJvm("-XX:-UseSerialGC",
                                                      "-XX:-UseParallelGC",
                                                      "-XX:-UseG1GC",
                                                      "-XX:-UseConcMarkSweepGC",
                                                      "-XX:+UnlockExperimentalVMOptions",
                                                      "-XX:-UseZGC",
                                                      "-version");
        OutputAnalyzer output = new OutputAnalyzer(pb.start());
        output.shouldMatch("Garbage collector not selected");
        output.shouldHaveExitValue(1);
    }
}
